@@ -278,11 +278,11 @@ def LoadConfig():
             data.Yscale_Movement=data.Yscale_Movement_default
             config.set('main', 'Yscale_Movement', str(data.Yscale_Movement_default))
 
-            QMessageBox.critical(None, "Changes in SleepAnalyser",
-            "There are many new functions and changes in SleepAnalyser. " + \
-            "Please have a look in the help menu to see what has changed. " + \
-            "Because of the changes some parameters might need adjustment. " + \
-            "You can change them in the configuration dialog.")
+        QMessageBox.critical(None, "Changes in SleepAnalyser",
+        "There are many new functions and changes in SleepAnalyser. " + \
+        "Please have a look in the help menu to see what has changed. " + \
+        "Because of the changes some parameters might need readjustment. " + \
+        "You can change them in the configuration menu.")
 
     else: #config file up to date
         pass
