@@ -63,10 +63,11 @@ def ErrorReportDialog(trace,txt_email=None):
     txt=string.replace(trace, "  File \"/opt/SleepAnalyser/", "\"")
     arr=txt.split("\n")
 #    print arr
-    txt="Please inform the author with an email (george@ruinelli.ch) and attach the log file "+data.LogFile+"\n[...]"
+#    txt="Please inform the author with an email (george@ruinelli.ch) and attach the log file "+data.LogFile+"\n[...]"
+    txt=""
     for i in range(len(arr)-5, len(arr)-1): txt=txt+arr[i]+"\n"
 
-    QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt) #Max 11 lines in dialog!
+    QMessageBox.critical(None, "Oops! Error in SleepAnalyser "+data.version+"-"+data.build, txt, QMessageBox.Ok) #Max 11 lines in dialog!
 #    r=QInputDialog.getText(None, "Add Note", trace, QLineEdit.Normal, "---\nlll\nkkk")
 
 
@@ -77,4 +78,4 @@ def ErrorReportDialog(trace,txt_email=None):
 
 #Small test of a use from a about menu for example
 if __name__ == "__main__":
-    pass
\ No newline at end of file
+    pass
